@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime, date
 from django.db import models
 from django.conf import settings
 from django.utils.functional import curry
@@ -10,6 +10,7 @@ def _flag_FIELD_as_stale(self, field=None, and_recalculate=None, commit=True):
         and_recalculate = True
         if hasattr(settings, 'CACHED_FIELD_EAGER_RECALCULATION'):
             and_recalculate = settings.CACHED_FIELD_EAGER_RECALCULATION
+    #:MC: this could be improved by checking the database instead of the object, but doing so would add a query per flag
     if not getattr(self, field.recalculation_needed_field_name):
         setattr(self, field.recalculation_needed_field_name, True)
         kwargs = {field.recalculation_needed_field_name: True}
@@ -23,6 +24,8 @@ def _flag_FIELD_as_stale(self, field=None, and_recalculate=None, commit=True):
 
 
 def _expire_FIELD_after(self, when=None, field=None):
+    if when is not None and isinstance(when, date):
+        when = datetime(when.year, when.month, when.day, 0, 0, 0)
     setattr(self, field.expiration_field_name, when)
     type(self).objects.filter(pk=self.pk).update(**{field.expiration_field_name: when})
 
